@@ -16,8 +16,19 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
+
+from google.cloud.recommendationengine_v1beta1 import gapic_version as package_version
 
 from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
@@ -56,7 +67,10 @@ class CatalogServiceAsyncClient:
 
     catalog_path = staticmethod(CatalogServiceClient.catalog_path)
     parse_catalog_path = staticmethod(CatalogServiceClient.parse_catalog_path)
-
+    catalog_item_path_path = staticmethod(CatalogServiceClient.catalog_item_path_path)
+    parse_catalog_item_path_path = staticmethod(
+        CatalogServiceClient.parse_catalog_item_path_path
+    )
     common_billing_account_path = staticmethod(
         CatalogServiceClient.common_billing_account_path
     )
@@ -131,7 +145,7 @@ class CatalogServiceAsyncClient:
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -167,9 +181,9 @@ class CatalogServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, CatalogServiceTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the catalog service client.
@@ -213,12 +227,12 @@ class CatalogServiceAsyncClient:
 
     async def create_catalog_item(
         self,
-        request: Union[catalog_service.CreateCatalogItemRequest, dict] = None,
+        request: Optional[Union[catalog_service.CreateCatalogItemRequest, dict]] = None,
         *,
-        parent: str = None,
-        catalog_item: catalog.CatalogItem = None,
+        parent: Optional[str] = None,
+        catalog_item: Optional[catalog.CatalogItem] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> catalog.CatalogItem:
         r"""Creates a catalog item.
@@ -256,9 +270,9 @@ class CatalogServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.recommendationengine_v1beta1.types.CreateCatalogItemRequest, dict]):
-                The request object. Request message for
-                CreateCatalogItem method.
+            request (Optional[Union[google.cloud.recommendationengine_v1beta1.types.CreateCatalogItemRequest, dict]]):
+                The request object. Request message for CreateCatalogItem
+                method.
             parent (:class:`str`):
                 Required. The parent catalog resource name, such as
                 ``projects/*/locations/global/catalogs/default_catalog``.
@@ -339,11 +353,11 @@ class CatalogServiceAsyncClient:
 
     async def get_catalog_item(
         self,
-        request: Union[catalog_service.GetCatalogItemRequest, dict] = None,
+        request: Optional[Union[catalog_service.GetCatalogItemRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> catalog.CatalogItem:
         r"""Gets a specific catalog item.
@@ -375,7 +389,7 @@ class CatalogServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.recommendationengine_v1beta1.types.GetCatalogItemRequest, dict]):
+            request (Optional[Union[google.cloud.recommendationengine_v1beta1.types.GetCatalogItemRequest, dict]]):
                 The request object. Request message for GetCatalogItem
                 method.
             name (:class:`str`):
@@ -451,12 +465,12 @@ class CatalogServiceAsyncClient:
 
     async def list_catalog_items(
         self,
-        request: Union[catalog_service.ListCatalogItemsRequest, dict] = None,
+        request: Optional[Union[catalog_service.ListCatalogItemsRequest, dict]] = None,
         *,
-        parent: str = None,
-        filter: str = None,
+        parent: Optional[str] = None,
+        filter: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListCatalogItemsAsyncPager:
         r"""Gets a list of catalog items.
@@ -489,7 +503,7 @@ class CatalogServiceAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.recommendationengine_v1beta1.types.ListCatalogItemsRequest, dict]):
+            request (Optional[Union[google.cloud.recommendationengine_v1beta1.types.ListCatalogItemsRequest, dict]]):
                 The request object. Request message for ListCatalogItems
                 method.
             parent (:class:`str`):
@@ -586,13 +600,13 @@ class CatalogServiceAsyncClient:
 
     async def update_catalog_item(
         self,
-        request: Union[catalog_service.UpdateCatalogItemRequest, dict] = None,
+        request: Optional[Union[catalog_service.UpdateCatalogItemRequest, dict]] = None,
         *,
-        name: str = None,
-        catalog_item: catalog.CatalogItem = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        name: Optional[str] = None,
+        catalog_item: Optional[catalog.CatalogItem] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> catalog.CatalogItem:
         r"""Updates a catalog item. Partial updating is
@@ -631,12 +645,12 @@ class CatalogServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.recommendationengine_v1beta1.types.UpdateCatalogItemRequest, dict]):
-                The request object. Request message for
-                UpdateCatalogItem method.
+            request (Optional[Union[google.cloud.recommendationengine_v1beta1.types.UpdateCatalogItemRequest, dict]]):
+                The request object. Request message for UpdateCatalogItem
+                method.
             name (:class:`str`):
                 Required. Full resource name of catalog item, such as
-                ``projects/*/locations/global/catalogs/default_catalog/catalogItems/some_catalog_item_id``
+                ``projects/*/locations/global/catalogs/default_catalog/catalogItems/some_catalog_item_id``.
 
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -726,11 +740,11 @@ class CatalogServiceAsyncClient:
 
     async def delete_catalog_item(
         self,
-        request: Union[catalog_service.DeleteCatalogItemRequest, dict] = None,
+        request: Optional[Union[catalog_service.DeleteCatalogItemRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes a catalog item.
@@ -759,9 +773,9 @@ class CatalogServiceAsyncClient:
                 await client.delete_catalog_item(request=request)
 
         Args:
-            request (Union[google.cloud.recommendationengine_v1beta1.types.DeleteCatalogItemRequest, dict]):
-                The request object. Request message for
-                DeleteCatalogItem method.
+            request (Optional[Union[google.cloud.recommendationengine_v1beta1.types.DeleteCatalogItemRequest, dict]]):
+                The request object. Request message for DeleteCatalogItem
+                method.
             name (:class:`str`):
                 Required. Full resource name of catalog item, such as
                 ``projects/*/locations/global/catalogs/default_catalog/catalogItems/some_catalog_item_id``.
@@ -826,14 +840,14 @@ class CatalogServiceAsyncClient:
 
     async def import_catalog_items(
         self,
-        request: Union[import_.ImportCatalogItemsRequest, dict] = None,
+        request: Optional[Union[import_.ImportCatalogItemsRequest, dict]] = None,
         *,
-        parent: str = None,
-        request_id: str = None,
-        input_config: import_.InputConfig = None,
-        errors_config: import_.ImportErrorsConfig = None,
+        parent: Optional[str] = None,
+        request_id: Optional[str] = None,
+        input_config: Optional[import_.InputConfig] = None,
+        errors_config: Optional[import_.ImportErrorsConfig] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Bulk import of multiple catalog items. Request
@@ -869,13 +883,13 @@ class CatalogServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.recommendationengine_v1beta1.types.ImportCatalogItemsRequest, dict]):
+            request (Optional[Union[google.cloud.recommendationengine_v1beta1.types.ImportCatalogItemsRequest, dict]]):
                 The request object. Request message for Import methods.
             parent (:class:`str`):
                 Required.
@@ -1000,14 +1014,9 @@ class CatalogServiceAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-recommendations-ai",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("CatalogServiceAsyncClient",)
