@@ -31,7 +31,7 @@ from google.api_core import operations_v1
 from requests import __version__ as requests_version
 import dataclasses
 import re
-from typing import Callable, Dict, List, Optional, Sequence, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
 import warnings
 
 try:
@@ -74,44 +74,49 @@ class CatalogServiceRestInterceptor:
 
     .. code-block:: python
         class MyCustomCatalogServiceInterceptor(CatalogServiceRestInterceptor):
-            def pre_create_catalog_item(request, metadata):
+            def pre_create_catalog_item(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_create_catalog_item(response):
+            def post_create_catalog_item(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_delete_catalog_item(request, metadata):
+            def pre_delete_catalog_item(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def pre_get_catalog_item(request, metadata):
+            def pre_get_catalog_item(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_get_catalog_item(response):
+            def post_get_catalog_item(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_import_catalog_items(request, metadata):
+            def pre_import_catalog_items(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_import_catalog_items(response):
+            def post_import_catalog_items(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_list_catalog_items(request, metadata):
+            def pre_list_catalog_items(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_list_catalog_items(response):
+            def post_list_catalog_items(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_update_catalog_item(request, metadata):
+            def pre_update_catalog_item(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_update_catalog_item(response):
+            def post_update_catalog_item(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
         transport = CatalogServiceRestTransport(interceptor=MyCustomCatalogServiceInterceptor())
         client = CatalogServiceClient(transport=transport)
@@ -266,19 +271,16 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
 
     It sends JSON representations of protocol buffers over HTTP/1.1
 
-    NOTE: This REST transport functionality is currently in a beta
-    state (preview). We welcome your feedback via an issue in this
-    library's source repository. Thank you!
     """
 
     def __init__(
         self,
         *,
         host: str = "recommendationengine.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
-        credentials_file: str = None,
-        scopes: Sequence[str] = None,
-        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
+        credentials_file: Optional[str] = None,
+        scopes: Optional[Sequence[str]] = None,
+        client_cert_source_for_mtls: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
@@ -288,39 +290,35 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
     ) -> None:
         """Instantiate the transport.
 
-        NOTE: This REST transport functionality is currently in a beta
-        state (preview). We welcome your feedback via a GitHub issue in
-        this library's repository. Thank you!
+        Args:
+            host (Optional[str]):
+                 The hostname to connect to.
+            credentials (Optional[google.auth.credentials.Credentials]): The
+                authorization credentials to attach to requests. These
+                credentials identify the application to the service; if none
+                are specified, the client will attempt to ascertain the
+                credentials from the environment.
 
-         Args:
-             host (Optional[str]):
-                  The hostname to connect to.
-             credentials (Optional[google.auth.credentials.Credentials]): The
-                 authorization credentials to attach to requests. These
-                 credentials identify the application to the service; if none
-                 are specified, the client will attempt to ascertain the
-                 credentials from the environment.
-
-             credentials_file (Optional[str]): A file with credentials that can
-                 be loaded with :func:`google.auth.load_credentials_from_file`.
-                 This argument is ignored if ``channel`` is provided.
-             scopes (Optional(Sequence[str])): A list of scopes. This argument is
-                 ignored if ``channel`` is provided.
-             client_cert_source_for_mtls (Callable[[], Tuple[bytes, bytes]]): Client
-                 certificate to configure mutual TLS HTTP channel. It is ignored
-                 if ``channel`` is provided.
-             quota_project_id (Optional[str]): An optional project to use for billing
-                 and quota.
-             client_info (google.api_core.gapic_v1.client_info.ClientInfo):
-                 The client info used to send a user-agent string along with
-                 API requests. If ``None``, then default info will be used.
-                 Generally, you only need to set this if you are developing
-                 your own client library.
-             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
-                 be used for service account credentials.
-             url_scheme: the protocol scheme for the API endpoint.  Normally
-                 "https", but for testing or local servers,
-                 "http" can be specified.
+            credentials_file (Optional[str]): A file with credentials that can
+                be loaded with :func:`google.auth.load_credentials_from_file`.
+                This argument is ignored if ``channel`` is provided.
+            scopes (Optional(Sequence[str])): A list of scopes. This argument is
+                ignored if ``channel`` is provided.
+            client_cert_source_for_mtls (Callable[[], Tuple[bytes, bytes]]): Client
+                certificate to configure mutual TLS HTTP channel. It is ignored
+                if ``channel`` is provided.
+            quota_project_id (Optional[str]): An optional project to use for billing
+                and quota.
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you are developing
+                your own client library.
+            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
+                be used for service account credentials.
+            url_scheme: the protocol scheme for the API endpoint.  Normally
+                "https", but for testing or local servers,
+                "http" can be specified.
         """
         # Run the base constructor
         # TODO(yon-mg): resolve other ctor params i.e. scopes, quota, etc.
@@ -361,7 +359,28 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
         """
         # Only create a new client if we do not already have one.
         if self._operations_client is None:
-            http_options: Dict[str, List[Dict[str, str]]] = {}
+            http_options: Dict[str, List[Dict[str, str]]] = {
+                "google.longrunning.Operations.GetOperation": [
+                    {
+                        "method": "get",
+                        "uri": "/v1beta1/{name=projects/*/locations/*/catalogs/*/operations/*}",
+                    },
+                    {
+                        "method": "get",
+                        "uri": "/v1beta1/{name=projects/*/locations/*/catalogs/*/eventStores/*/operations/*}",
+                    },
+                ],
+                "google.longrunning.Operations.ListOperations": [
+                    {
+                        "method": "get",
+                        "uri": "/v1beta1/{name=projects/*/locations/*/catalogs/*}/operations",
+                    },
+                    {
+                        "method": "get",
+                        "uri": "/v1beta1/{name=projects/*/locations/*/catalogs/*/eventStores/*}/operations",
+                    },
+                ],
+            }
 
             rest_transport = operations_v1.OperationsRestTransport(
                 host=self._host,
@@ -369,6 +388,7 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
                 credentials=self._credentials,
                 scopes=self._scopes,
                 http_options=http_options,
+                path_prefix="v1beta1",
             )
 
             self._operations_client = operations_v1.AbstractOperationsClient(
@@ -382,7 +402,7 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
         def __hash__(self):
             return hash("CreateCatalogItem")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -397,7 +417,7 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
             request: catalog_service.CreateCatalogItemRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> catalog.CatalogItem:
             r"""Call the create catalog item method over HTTP.
@@ -406,7 +426,6 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
                 request (~.catalog_service.CreateCatalogItemRequest):
                     The request object. Request message for CreateCatalogItem
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -438,7 +457,7 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
             body = json_format.MessageToJson(
                 transcoded_request["body"],
                 including_default_value_fields=False,
-                use_integers_for_enums=False,
+                use_integers_for_enums=True,
             )
             uri = transcoded_request["uri"]
             method = transcoded_request["method"]
@@ -448,11 +467,13 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
                 json_format.MessageToJson(
                     transcoded_request["query_params"],
                     including_default_value_fields=False,
-                    use_integers_for_enums=False,
+                    use_integers_for_enums=True,
                 )
             )
             query_params.update(self._get_unset_required_fields(query_params))
 
+            query_params["$alt"] = "json;enum-encoding=int"
+
             # Send the request
             headers = dict(metadata)
             headers["Content-Type"] = "application/json"
@@ -481,7 +502,7 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
         def __hash__(self):
             return hash("DeleteCatalogItem")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -496,7 +517,7 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
             request: catalog_service.DeleteCatalogItemRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ):
             r"""Call the delete catalog item method over HTTP.
@@ -505,7 +526,6 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
                 request (~.catalog_service.DeleteCatalogItemRequest):
                     The request object. Request message for DeleteCatalogItem
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -533,11 +553,13 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
                 json_format.MessageToJson(
                     transcoded_request["query_params"],
                     including_default_value_fields=False,
-                    use_integers_for_enums=False,
+                    use_integers_for_enums=True,
                 )
             )
             query_params.update(self._get_unset_required_fields(query_params))
 
+            query_params["$alt"] = "json;enum-encoding=int"
+
             # Send the request
             headers = dict(metadata)
             headers["Content-Type"] = "application/json"
@@ -557,7 +579,7 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
         def __hash__(self):
             return hash("GetCatalogItem")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -572,7 +594,7 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
             request: catalog_service.GetCatalogItemRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> catalog.CatalogItem:
             r"""Call the get catalog item method over HTTP.
@@ -581,7 +603,6 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
                 request (~.catalog_service.GetCatalogItemRequest):
                     The request object. Request message for GetCatalogItem
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -615,11 +636,13 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
                 json_format.MessageToJson(
                     transcoded_request["query_params"],
                     including_default_value_fields=False,
-                    use_integers_for_enums=False,
+                    use_integers_for_enums=True,
                 )
             )
             query_params.update(self._get_unset_required_fields(query_params))
 
+            query_params["$alt"] = "json;enum-encoding=int"
+
             # Send the request
             headers = dict(metadata)
             headers["Content-Type"] = "application/json"
@@ -647,7 +670,7 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
         def __hash__(self):
             return hash("ImportCatalogItems")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -662,7 +685,7 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
             request: import_.ImportCatalogItemsRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> operations_pb2.Operation:
             r"""Call the import catalog items method over HTTP.
@@ -702,7 +725,7 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
             body = json_format.MessageToJson(
                 transcoded_request["body"],
                 including_default_value_fields=False,
-                use_integers_for_enums=False,
+                use_integers_for_enums=True,
             )
             uri = transcoded_request["uri"]
             method = transcoded_request["method"]
@@ -712,11 +735,13 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
                 json_format.MessageToJson(
                     transcoded_request["query_params"],
                     including_default_value_fields=False,
-                    use_integers_for_enums=False,
+                    use_integers_for_enums=True,
                 )
             )
             query_params.update(self._get_unset_required_fields(query_params))
 
+            query_params["$alt"] = "json;enum-encoding=int"
+
             # Send the request
             headers = dict(metadata)
             headers["Content-Type"] = "application/json"
@@ -743,7 +768,7 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
         def __hash__(self):
             return hash("ListCatalogItems")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -758,7 +783,7 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
             request: catalog_service.ListCatalogItemsRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> catalog_service.ListCatalogItemsResponse:
             r"""Call the list catalog items method over HTTP.
@@ -767,7 +792,6 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
                 request (~.catalog_service.ListCatalogItemsRequest):
                     The request object. Request message for ListCatalogItems
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -801,11 +825,13 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
                 json_format.MessageToJson(
                     transcoded_request["query_params"],
                     including_default_value_fields=False,
-                    use_integers_for_enums=False,
+                    use_integers_for_enums=True,
                 )
             )
             query_params.update(self._get_unset_required_fields(query_params))
 
+            query_params["$alt"] = "json;enum-encoding=int"
+
             # Send the request
             headers = dict(metadata)
             headers["Content-Type"] = "application/json"
@@ -833,7 +859,7 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
         def __hash__(self):
             return hash("UpdateCatalogItem")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -848,7 +874,7 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
             request: catalog_service.UpdateCatalogItemRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> catalog.CatalogItem:
             r"""Call the update catalog item method over HTTP.
@@ -857,7 +883,6 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
                 request (~.catalog_service.UpdateCatalogItemRequest):
                     The request object. Request message for UpdateCatalogItem
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -889,7 +914,7 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
             body = json_format.MessageToJson(
                 transcoded_request["body"],
                 including_default_value_fields=False,
-                use_integers_for_enums=False,
+                use_integers_for_enums=True,
             )
             uri = transcoded_request["uri"]
             method = transcoded_request["method"]
@@ -899,11 +924,13 @@ class CatalogServiceRestTransport(CatalogServiceTransport):
                 json_format.MessageToJson(
                     transcoded_request["query_params"],
                     including_default_value_fields=False,
-                    use_integers_for_enums=False,
+                    use_integers_for_enums=True,
                 )
             )
             query_params.update(self._get_unset_required_fields(query_params))
 
+            query_params["$alt"] = "json;enum-encoding=int"
+
             # Send the request
             headers = dict(metadata)
             headers["Content-Type"] = "application/json"
