@@ -16,8 +16,19 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
+
+from google.cloud.recommendationengine_v1beta1 import gapic_version as package_version
 
 from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
@@ -144,7 +155,7 @@ class PredictionApiKeyRegistryAsyncClient:
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -181,9 +192,9 @@ class PredictionApiKeyRegistryAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, PredictionApiKeyRegistryTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the prediction api key registry client.
@@ -227,15 +238,19 @@ class PredictionApiKeyRegistryAsyncClient:
 
     async def create_prediction_api_key_registration(
         self,
-        request: Union[
-            prediction_apikey_registry_service.CreatePredictionApiKeyRegistrationRequest,
-            dict,
+        request: Optional[
+            Union[
+                prediction_apikey_registry_service.CreatePredictionApiKeyRegistrationRequest,
+                dict,
+            ]
         ] = None,
         *,
-        parent: str = None,
-        prediction_api_key_registration: prediction_apikey_registry_service.PredictionApiKeyRegistration = None,
+        parent: Optional[str] = None,
+        prediction_api_key_registration: Optional[
+            prediction_apikey_registry_service.PredictionApiKeyRegistration
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> prediction_apikey_registry_service.PredictionApiKeyRegistration:
         r"""Register an API key for use with predict method.
@@ -267,9 +282,9 @@ class PredictionApiKeyRegistryAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.recommendationengine_v1beta1.types.CreatePredictionApiKeyRegistrationRequest, dict]):
+            request (Optional[Union[google.cloud.recommendationengine_v1beta1.types.CreatePredictionApiKeyRegistrationRequest, dict]]):
                 The request object. Request message for the
-                `CreatePredictionApiKeyRegistration` method.
+                ``CreatePredictionApiKeyRegistration`` method.
             parent (:class:`str`):
                 Required. The parent resource path.
                 ``projects/*/locations/global/catalogs/default_catalog/eventStores/default_event_store``.
@@ -352,14 +367,16 @@ class PredictionApiKeyRegistryAsyncClient:
 
     async def list_prediction_api_key_registrations(
         self,
-        request: Union[
-            prediction_apikey_registry_service.ListPredictionApiKeyRegistrationsRequest,
-            dict,
+        request: Optional[
+            Union[
+                prediction_apikey_registry_service.ListPredictionApiKeyRegistrationsRequest,
+                dict,
+            ]
         ] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPredictionApiKeyRegistrationsAsyncPager:
         r"""List the registered apiKeys for use with predict
@@ -393,9 +410,9 @@ class PredictionApiKeyRegistryAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.recommendationengine_v1beta1.types.ListPredictionApiKeyRegistrationsRequest, dict]):
+            request (Optional[Union[google.cloud.recommendationengine_v1beta1.types.ListPredictionApiKeyRegistrationsRequest, dict]]):
                 The request object. Request message for the
-                `ListPredictionApiKeyRegistrations`.
+                ``ListPredictionApiKeyRegistrations``.
             parent (:class:`str`):
                 Required. The parent placement resource name such as
                 ``projects/1234/locations/global/catalogs/default_catalog/eventStores/default_event_store``
@@ -485,14 +502,16 @@ class PredictionApiKeyRegistryAsyncClient:
 
     async def delete_prediction_api_key_registration(
         self,
-        request: Union[
-            prediction_apikey_registry_service.DeletePredictionApiKeyRegistrationRequest,
-            dict,
+        request: Optional[
+            Union[
+                prediction_apikey_registry_service.DeletePredictionApiKeyRegistrationRequest,
+                dict,
+            ]
         ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Unregister an apiKey from using for predict method.
@@ -521,9 +540,9 @@ class PredictionApiKeyRegistryAsyncClient:
                 await client.delete_prediction_api_key_registration(request=request)
 
         Args:
-            request (Union[google.cloud.recommendationengine_v1beta1.types.DeletePredictionApiKeyRegistrationRequest, dict]):
+            request (Optional[Union[google.cloud.recommendationengine_v1beta1.types.DeletePredictionApiKeyRegistrationRequest, dict]]):
                 The request object. Request message for
-                `DeletePredictionApiKeyRegistration` method.
+                ``DeletePredictionApiKeyRegistration`` method.
             name (:class:`str`):
                 Required. The API key to unregister including full
                 resource path.
@@ -596,14 +615,9 @@ class PredictionApiKeyRegistryAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-recommendations-ai",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("PredictionApiKeyRegistryAsyncClient",)
