@@ -16,8 +16,19 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
+
+from google.cloud.recommendationengine_v1beta1 import gapic_version as package_version
 
 from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
@@ -132,7 +143,7 @@ class UserEventServiceAsyncClient:
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -168,9 +179,9 @@ class UserEventServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, UserEventServiceTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the user event service client.
@@ -214,12 +225,12 @@ class UserEventServiceAsyncClient:
 
     async def write_user_event(
         self,
-        request: Union[user_event_service.WriteUserEventRequest, dict] = None,
+        request: Optional[Union[user_event_service.WriteUserEventRequest, dict]] = None,
         *,
-        parent: str = None,
-        user_event: gcr_user_event.UserEvent = None,
+        parent: Optional[str] = None,
+        user_event: Optional[gcr_user_event.UserEvent] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gcr_user_event.UserEvent:
         r"""Writes a single user event.
@@ -256,7 +267,7 @@ class UserEventServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.recommendationengine_v1beta1.types.WriteUserEventRequest, dict]):
+            request (Optional[Union[google.cloud.recommendationengine_v1beta1.types.WriteUserEventRequest, dict]]):
                 The request object. Request message for WriteUserEvent
                 method.
             parent (:class:`str`):
@@ -341,14 +352,16 @@ class UserEventServiceAsyncClient:
 
     async def collect_user_event(
         self,
-        request: Union[user_event_service.CollectUserEventRequest, dict] = None,
+        request: Optional[
+            Union[user_event_service.CollectUserEventRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
-        user_event: str = None,
-        uri: str = None,
-        ets: int = None,
+        parent: Optional[str] = None,
+        user_event: Optional[str] = None,
+        uri: Optional[str] = None,
+        ets: Optional[int] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> httpbody_pb2.HttpBody:
         r"""Writes a single user event from the browser. This
@@ -386,7 +399,7 @@ class UserEventServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.recommendationengine_v1beta1.types.CollectUserEventRequest, dict]):
+            request (Optional[Union[google.cloud.recommendationengine_v1beta1.types.CollectUserEventRequest, dict]]):
                 The request object. Request message for CollectUserEvent
                 method.
             parent (:class:`str`):
@@ -542,12 +555,12 @@ class UserEventServiceAsyncClient:
 
     async def list_user_events(
         self,
-        request: Union[user_event_service.ListUserEventsRequest, dict] = None,
+        request: Optional[Union[user_event_service.ListUserEventsRequest, dict]] = None,
         *,
-        parent: str = None,
-        filter: str = None,
+        parent: Optional[str] = None,
+        filter: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListUserEventsAsyncPager:
         r"""Gets a list of user events within a time range, with
@@ -581,7 +594,7 @@ class UserEventServiceAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.recommendationengine_v1beta1.types.ListUserEventsRequest, dict]):
+            request (Optional[Union[google.cloud.recommendationengine_v1beta1.types.ListUserEventsRequest, dict]]):
                 The request object. Request message for ListUserEvents
                 method.
             parent (:class:`str`):
@@ -712,13 +725,15 @@ class UserEventServiceAsyncClient:
 
     async def purge_user_events(
         self,
-        request: Union[user_event_service.PurgeUserEventsRequest, dict] = None,
+        request: Optional[
+            Union[user_event_service.PurgeUserEventsRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
-        filter: str = None,
-        force: bool = None,
+        parent: Optional[str] = None,
+        filter: Optional[str] = None,
+        force: Optional[bool] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Deletes permanently all user events specified by the
@@ -753,13 +768,13 @@ class UserEventServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.recommendationengine_v1beta1.types.PurgeUserEventsRequest, dict]):
+            request (Optional[Union[google.cloud.recommendationengine_v1beta1.types.PurgeUserEventsRequest, dict]]):
                 The request object. Request message for PurgeUserEvents
                 method.
             parent (:class:`str`):
@@ -885,14 +900,14 @@ class UserEventServiceAsyncClient:
 
     async def import_user_events(
         self,
-        request: Union[import_.ImportUserEventsRequest, dict] = None,
+        request: Optional[Union[import_.ImportUserEventsRequest, dict]] = None,
         *,
-        parent: str = None,
-        request_id: str = None,
-        input_config: import_.InputConfig = None,
-        errors_config: import_.ImportErrorsConfig = None,
+        parent: Optional[str] = None,
+        request_id: Optional[str] = None,
+        input_config: Optional[import_.InputConfig] = None,
+        errors_config: Optional[import_.ImportErrorsConfig] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Bulk import of User events. Request processing might
@@ -928,13 +943,13 @@ class UserEventServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.recommendationengine_v1beta1.types.ImportUserEventsRequest, dict]):
+            request (Optional[Union[google.cloud.recommendationengine_v1beta1.types.ImportUserEventsRequest, dict]]):
                 The request object. Request message for the
                 ImportUserEvents request.
             parent (:class:`str`):
@@ -1060,14 +1075,9 @@ class UserEventServiceAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-recommendations-ai",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("UserEventServiceAsyncClient",)
