@@ -31,7 +31,7 @@ from google.api_core import operations_v1
 from requests import __version__ as requests_version
 import dataclasses
 import re
-from typing import Callable, Dict, List, Optional, Sequence, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
 import warnings
 
 try:
@@ -74,40 +74,45 @@ class UserEventServiceRestInterceptor:
 
     .. code-block:: python
         class MyCustomUserEventServiceInterceptor(UserEventServiceRestInterceptor):
-            def pre_collect_user_event(request, metadata):
+            def pre_collect_user_event(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_collect_user_event(response):
+            def post_collect_user_event(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_import_user_events(request, metadata):
+            def pre_import_user_events(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_import_user_events(response):
+            def post_import_user_events(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_list_user_events(request, metadata):
+            def pre_list_user_events(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_list_user_events(response):
+            def post_list_user_events(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_purge_user_events(request, metadata):
+            def pre_purge_user_events(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_purge_user_events(response):
+            def post_purge_user_events(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_write_user_event(request, metadata):
+            def pre_write_user_event(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_write_user_event(response):
+            def post_write_user_event(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
         transport = UserEventServiceRestTransport(interceptor=MyCustomUserEventServiceInterceptor())
         client = UserEventServiceClient(transport=transport)
@@ -250,19 +255,16 @@ class UserEventServiceRestTransport(UserEventServiceTransport):
 
     It sends JSON representations of protocol buffers over HTTP/1.1
 
-    NOTE: This REST transport functionality is currently in a beta
-    state (preview). We welcome your feedback via an issue in this
-    library's source repository. Thank you!
     """
 
     def __init__(
         self,
         *,
         host: str = "recommendationengine.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
-        credentials_file: str = None,
-        scopes: Sequence[str] = None,
-        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
+        credentials_file: Optional[str] = None,
+        scopes: Optional[Sequence[str]] = None,
+        client_cert_source_for_mtls: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
@@ -272,39 +274,35 @@ class UserEventServiceRestTransport(UserEventServiceTransport):
     ) -> None:
         """Instantiate the transport.
 
-        NOTE: This REST transport functionality is currently in a beta
-        state (preview). We welcome your feedback via a GitHub issue in
-        this library's repository. Thank you!
+        Args:
+            host (Optional[str]):
+                 The hostname to connect to.
+            credentials (Optional[google.auth.credentials.Credentials]): The
+                authorization credentials to attach to requests. These
+                credentials identify the application to the service; if none
+                are specified, the client will attempt to ascertain the
+                credentials from the environment.
 
-         Args:
-             host (Optional[str]):
-                  The hostname to connect to.
-             credentials (Optional[google.auth.credentials.Credentials]): The
-                 authorization credentials to attach to requests. These
-                 credentials identify the application to the service; if none
-                 are specified, the client will attempt to ascertain the
-                 credentials from the environment.
-
-             credentials_file (Optional[str]): A file with credentials that can
-                 be loaded with :func:`google.auth.load_credentials_from_file`.
-                 This argument is ignored if ``channel`` is provided.
-             scopes (Optional(Sequence[str])): A list of scopes. This argument is
-                 ignored if ``channel`` is provided.
-             client_cert_source_for_mtls (Callable[[], Tuple[bytes, bytes]]): Client
-                 certificate to configure mutual TLS HTTP channel. It is ignored
-                 if ``channel`` is provided.
-             quota_project_id (Optional[str]): An optional project to use for billing
-                 and quota.
-             client_info (google.api_core.gapic_v1.client_info.ClientInfo):
-                 The client info used to send a user-agent string along with
-                 API requests. If ``None``, then default info will be used.
-                 Generally, you only need to set this if you are developing
-                 your own client library.
-             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
-                 be used for service account credentials.
-             url_scheme: the protocol scheme for the API endpoint.  Normally
-                 "https", but for testing or local servers,
-                 "http" can be specified.
+            credentials_file (Optional[str]): A file with credentials that can
+                be loaded with :func:`google.auth.load_credentials_from_file`.
+                This argument is ignored if ``channel`` is provided.
+            scopes (Optional(Sequence[str])): A list of scopes. This argument is
+                ignored if ``channel`` is provided.
+            client_cert_source_for_mtls (Callable[[], Tuple[bytes, bytes]]): Client
+                certificate to configure mutual TLS HTTP channel. It is ignored
+                if ``channel`` is provided.
+            quota_project_id (Optional[str]): An optional project to use for billing
+                and quota.
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you are developing
+                your own client library.
+            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
+                be used for service account credentials.
+            url_scheme: the protocol scheme for the API endpoint.  Normally
+                "https", but for testing or local servers,
+                "http" can be specified.
         """
         # Run the base constructor
         # TODO(yon-mg): resolve other ctor params i.e. scopes, quota, etc.
@@ -345,7 +343,28 @@ class UserEventServiceRestTransport(UserEventServiceTransport):
         """
         # Only create a new client if we do not already have one.
         if self._operations_client is None:
-            http_options: Dict[str, List[Dict[str, str]]] = {}
+            http_options: Dict[str, List[Dict[str, str]]] = {
+                "google.longrunning.Operations.GetOperation": [
+                    {
+                        "method": "get",
+                        "uri": "/v1beta1/{name=projects/*/locations/*/catalogs/*/operations/*}",
+                    },
+                    {
+                        "method": "get",
+                        "uri": "/v1beta1/{name=projects/*/locations/*/catalogs/*/eventStores/*/operations/*}",
+                    },
+                ],
+                "google.longrunning.Operations.ListOperations": [
+                    {
+                        "method": "get",
+                        "uri": "/v1beta1/{name=projects/*/locations/*/catalogs/*}/operations",
+                    },
+                    {
+                        "method": "get",
+                        "uri": "/v1beta1/{name=projects/*/locations/*/catalogs/*/eventStores/*}/operations",
+                    },
+                ],
+            }
 
             rest_transport = operations_v1.OperationsRestTransport(
                 host=self._host,
@@ -353,6 +372,7 @@ class UserEventServiceRestTransport(UserEventServiceTransport):
                 credentials=self._credentials,
                 scopes=self._scopes,
                 http_options=http_options,
+                path_prefix="v1beta1",
             )
 
             self._operations_client = operations_v1.AbstractOperationsClient(
@@ -366,7 +386,7 @@ class UserEventServiceRestTransport(UserEventServiceTransport):
         def __hash__(self):
             return hash("CollectUserEvent")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {
             "userEvent": "",
         }
 
@@ -383,7 +403,7 @@ class UserEventServiceRestTransport(UserEventServiceTransport):
             request: user_event_service.CollectUserEventRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> httpbody_pb2.HttpBody:
             r"""Call the collect user event method over HTTP.
@@ -392,7 +412,6 @@ class UserEventServiceRestTransport(UserEventServiceTransport):
                 request (~.user_event_service.CollectUserEventRequest):
                     The request object. Request message for CollectUserEvent
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -473,11 +492,13 @@ class UserEventServiceRestTransport(UserEventServiceTransport):
                 json_format.MessageToJson(
                     transcoded_request["query_params"],
                     including_default_value_fields=False,
-                    use_integers_for_enums=False,
+                    use_integers_for_enums=True,
                 )
             )
             query_params.update(self._get_unset_required_fields(query_params))
 
+            query_params["$alt"] = "json;enum-encoding=int"
+
             # Send the request
             headers = dict(metadata)
             headers["Content-Type"] = "application/json"
@@ -505,7 +526,7 @@ class UserEventServiceRestTransport(UserEventServiceTransport):
         def __hash__(self):
             return hash("ImportUserEvents")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -520,7 +541,7 @@ class UserEventServiceRestTransport(UserEventServiceTransport):
             request: import_.ImportUserEventsRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> operations_pb2.Operation:
             r"""Call the import user events method over HTTP.
@@ -529,7 +550,6 @@ class UserEventServiceRestTransport(UserEventServiceTransport):
                 request (~.import_.ImportUserEventsRequest):
                     The request object. Request message for the
                 ImportUserEvents request.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -562,7 +582,7 @@ class UserEventServiceRestTransport(UserEventServiceTransport):
             body = json_format.MessageToJson(
                 transcoded_request["body"],
                 including_default_value_fields=False,
-                use_integers_for_enums=False,
+                use_integers_for_enums=True,
             )
             uri = transcoded_request["uri"]
             method = transcoded_request["method"]
@@ -572,11 +592,13 @@ class UserEventServiceRestTransport(UserEventServiceTransport):
                 json_format.MessageToJson(
                     transcoded_request["query_params"],
                     including_default_value_fields=False,
-                    use_integers_for_enums=False,
+                    use_integers_for_enums=True,
                 )
             )
             query_params.update(self._get_unset_required_fields(query_params))
 
+            query_params["$alt"] = "json;enum-encoding=int"
+
             # Send the request
             headers = dict(metadata)
             headers["Content-Type"] = "application/json"
@@ -603,7 +625,7 @@ class UserEventServiceRestTransport(UserEventServiceTransport):
         def __hash__(self):
             return hash("ListUserEvents")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -618,7 +640,7 @@ class UserEventServiceRestTransport(UserEventServiceTransport):
             request: user_event_service.ListUserEventsRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> user_event_service.ListUserEventsResponse:
             r"""Call the list user events method over HTTP.
@@ -627,7 +649,6 @@ class UserEventServiceRestTransport(UserEventServiceTransport):
                 request (~.user_event_service.ListUserEventsRequest):
                     The request object. Request message for ListUserEvents
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -661,11 +682,13 @@ class UserEventServiceRestTransport(UserEventServiceTransport):
                 json_format.MessageToJson(
                     transcoded_request["query_params"],
                     including_default_value_fields=False,
-                    use_integers_for_enums=False,
+                    use_integers_for_enums=True,
                 )
             )
             query_params.update(self._get_unset_required_fields(query_params))
 
+            query_params["$alt"] = "json;enum-encoding=int"
+
             # Send the request
             headers = dict(metadata)
             headers["Content-Type"] = "application/json"
@@ -693,7 +716,7 @@ class UserEventServiceRestTransport(UserEventServiceTransport):
         def __hash__(self):
             return hash("PurgeUserEvents")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -708,7 +731,7 @@ class UserEventServiceRestTransport(UserEventServiceTransport):
             request: user_event_service.PurgeUserEventsRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> operations_pb2.Operation:
             r"""Call the purge user events method over HTTP.
@@ -717,7 +740,6 @@ class UserEventServiceRestTransport(UserEventServiceTransport):
                 request (~.user_event_service.PurgeUserEventsRequest):
                     The request object. Request message for PurgeUserEvents
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -750,7 +772,7 @@ class UserEventServiceRestTransport(UserEventServiceTransport):
             body = json_format.MessageToJson(
                 transcoded_request["body"],
                 including_default_value_fields=False,
-                use_integers_for_enums=False,
+                use_integers_for_enums=True,
             )
             uri = transcoded_request["uri"]
             method = transcoded_request["method"]
@@ -760,11 +782,13 @@ class UserEventServiceRestTransport(UserEventServiceTransport):
                 json_format.MessageToJson(
                     transcoded_request["query_params"],
                     including_default_value_fields=False,
-                    use_integers_for_enums=False,
+                    use_integers_for_enums=True,
                 )
             )
             query_params.update(self._get_unset_required_fields(query_params))
 
+            query_params["$alt"] = "json;enum-encoding=int"
+
             # Send the request
             headers = dict(metadata)
             headers["Content-Type"] = "application/json"
@@ -791,7 +815,7 @@ class UserEventServiceRestTransport(UserEventServiceTransport):
         def __hash__(self):
             return hash("WriteUserEvent")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -806,7 +830,7 @@ class UserEventServiceRestTransport(UserEventServiceTransport):
             request: user_event_service.WriteUserEventRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> gcr_user_event.UserEvent:
             r"""Call the write user event method over HTTP.
@@ -815,7 +839,6 @@ class UserEventServiceRestTransport(UserEventServiceTransport):
                 request (~.user_event_service.WriteUserEventRequest):
                     The request object. Request message for WriteUserEvent
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -849,7 +872,7 @@ class UserEventServiceRestTransport(UserEventServiceTransport):
             body = json_format.MessageToJson(
                 transcoded_request["body"],
                 including_default_value_fields=False,
-                use_integers_for_enums=False,
+                use_integers_for_enums=True,
             )
             uri = transcoded_request["uri"]
             method = transcoded_request["method"]
@@ -859,11 +882,13 @@ class UserEventServiceRestTransport(UserEventServiceTransport):
                 json_format.MessageToJson(
                     transcoded_request["query_params"],
                     including_default_value_fields=False,
-                    use_integers_for_enums=False,
+                    use_integers_for_enums=True,
                 )
             )
             query_params.update(self._get_unset_required_fields(query_params))
 
+            query_params["$alt"] = "json;enum-encoding=int"
+
             # Send the request
             headers = dict(metadata)
             headers["Content-Type"] = "application/json"
