@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,10 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+import proto  # type: ignore
 
 
 __protobuf__ = proto.module(
-    package="google.cloud.recommendationengine.v1beta1", manifest={},
+    package="google.cloud.recommendationengine.v1beta1",
+    manifest={},
 )
 
 
