@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from __future__ import annotations
+
+from typing import MutableMapping, MutableSequence
+
 import proto  # type: ignore
 
 from google.cloud.recommendationengine_v1beta1.types import catalog
@@ -101,20 +105,56 @@ class UserEvent(proto.Message):
     """
 
     class EventSource(proto.Enum):
-        r"""User event source."""
+        r"""User event source.
+
+        Values:
+            EVENT_SOURCE_UNSPECIFIED (0):
+                Unspecified event source.
+            AUTOML (1):
+                The event is ingested via a javascript pixel
+                or Recommendations AI Tag through automl
+                datalayer or JS Macros.
+            ECOMMERCE (2):
+                The event is ingested via Recommendations AI
+                Tag through Enhanced Ecommerce datalayer.
+            BATCH_UPLOAD (3):
+                The event is ingested via Import user events
+                API.
+        """
         EVENT_SOURCE_UNSPECIFIED = 0
         AUTOML = 1
         ECOMMERCE = 2
         BATCH_UPLOAD = 3
 
-    event_type = proto.Field(proto.STRING, number=1,)
-    user_info = proto.Field(proto.MESSAGE, number=2, message="UserInfo",)
-    event_detail = proto.Field(proto.MESSAGE, number=3, message="EventDetail",)
-    product_event_detail = proto.Field(
-        proto.MESSAGE, number=4, message="ProductEventDetail",
+    event_type: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    user_info: "UserInfo" = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="UserInfo",
+    )
+    event_detail: "EventDetail" = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="EventDetail",
+    )
+    product_event_detail: "ProductEventDetail" = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message="ProductEventDetail",
+    )
+    event_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=timestamp_pb2.Timestamp,
+    )
+    event_source: EventSource = proto.Field(
+        proto.ENUM,
+        number=6,
+        enum=EventSource,
     )
-    event_time = proto.Field(proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,)
-    event_source = proto.Field(proto.ENUM, number=6, enum=EventSource,)
 
 
 class UserInfo(proto.Message):
@@ -158,11 +198,26 @@ class UserInfo(proto.Message):
             processing and pushing the user events).
     """
 
-    visitor_id = proto.Field(proto.STRING, number=1,)
-    user_id = proto.Field(proto.STRING, number=2,)
-    ip_address = proto.Field(proto.STRING, number=3,)
-    user_agent = proto.Field(proto.STRING, number=4,)
-    direct_user_request = proto.Field(proto.BOOL, number=5,)
+    visitor_id: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    user_id: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    ip_address: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    user_agent: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    direct_user_request: bool = proto.Field(
+        proto.BOOL,
+        number=5,
+    )
 
 
 class EventDetail(proto.Message):
@@ -187,7 +242,7 @@ class EventDetail(proto.Message):
             these events so that they can be grouped together properly.
             This ``pageViewId`` will be automatically generated if using
             the JavaScript pixel.
-        experiment_ids (Sequence[str]):
+        experiment_ids (MutableSequence[str]):
             Optional. A list of identifiers for the
             independent experiment groups this user event
             belongs to. This is used to distinguish between
@@ -222,12 +277,31 @@ class EventDetail(proto.Message):
             directly, or coming through Google search, and etc.
     """
 
-    uri = proto.Field(proto.STRING, number=1,)
-    referrer_uri = proto.Field(proto.STRING, number=6,)
-    page_view_id = proto.Field(proto.STRING, number=2,)
-    experiment_ids = proto.RepeatedField(proto.STRING, number=3,)
-    recommendation_token = proto.Field(proto.STRING, number=4,)
-    event_attributes = proto.Field(proto.MESSAGE, number=5, message=common.FeatureMap,)
+    uri: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    referrer_uri: str = proto.Field(
+        proto.STRING,
+        number=6,
+    )
+    page_view_id: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    experiment_ids: MutableSequence[str] = proto.RepeatedField(
+        proto.STRING,
+        number=3,
+    )
+    recommendation_token: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    event_attributes: common.FeatureMap = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=common.FeatureMap,
+    )
 
 
 class ProductEventDetail(proto.Message):
@@ -239,14 +313,14 @@ class ProductEventDetail(proto.Message):
             Required for ``search`` events. Other event types should not
             set this field. The user's search query as UTF-8 encoded
             text with a length limit of 5 KiB.
-        page_categories (Sequence[google.cloud.recommendationengine_v1beta1.types.CatalogItem.CategoryHierarchy]):
+        page_categories (MutableSequence[google.cloud.recommendationengine_v1beta1.types.CatalogItem.CategoryHierarchy]):
             Required for ``category-page-view`` events. Other event
             types should not set this field. The categories associated
             with a category page. Category pages include special pages
             such as sales or promotions. For instance, a special sale
             page may have the category hierarchy: categories : ["Sales",
             "2017 Black Friday Deals"].
-        product_details (Sequence[google.cloud.recommendationengine_v1beta1.types.ProductDetail]):
+        product_details (MutableSequence[google.cloud.recommendationengine_v1beta1.types.ProductDetail]):
             The main product details related to the event.
 
             This field is required for the following event types:
@@ -292,17 +366,34 @@ class ProductEventDetail(proto.Message):
             should not set this field.
     """
 
-    search_query = proto.Field(proto.STRING, number=1,)
-    page_categories = proto.RepeatedField(
-        proto.MESSAGE, number=2, message=catalog.CatalogItem.CategoryHierarchy,
+    search_query: str = proto.Field(
+        proto.STRING,
+        number=1,
     )
-    product_details = proto.RepeatedField(
-        proto.MESSAGE, number=3, message="ProductDetail",
+    page_categories: MutableSequence[
+        catalog.CatalogItem.CategoryHierarchy
+    ] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=2,
+        message=catalog.CatalogItem.CategoryHierarchy,
     )
-    list_id = proto.Field(proto.STRING, number=4,)
-    cart_id = proto.Field(proto.STRING, number=5,)
-    purchase_transaction = proto.Field(
-        proto.MESSAGE, number=6, message="PurchaseTransaction",
+    product_details: MutableSequence["ProductDetail"] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=3,
+        message="ProductDetail",
+    )
+    list_id: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    cart_id: str = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    purchase_transaction: "PurchaseTransaction" = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message="PurchaseTransaction",
     )
 
 
@@ -319,10 +410,10 @@ class PurchaseTransaction(proto.Message):
             adjustments to total revenue that you want to include as
             part of your revenue calculations. This field is not
             required if the event type is ``refund``.
-        taxes (Sequence[google.cloud.recommendationengine_v1beta1.types.PurchaseTransaction.TaxesEntry]):
+        taxes (MutableMapping[str, float]):
             Optional. All the taxes associated with the
             transaction.
-        costs (Sequence[google.cloud.recommendationengine_v1beta1.types.PurchaseTransaction.CostsEntry]):
+        costs (MutableMapping[str, float]):
             Optional. All the costs associated with the product. These
             can be manufacturing costs, shipping expenses not borne by
             the end user, or any other costs.
@@ -339,11 +430,28 @@ class PurchaseTransaction(proto.Message):
             This field is not required if the event type is ``refund``.
     """
 
-    id = proto.Field(proto.STRING, number=1,)
-    revenue = proto.Field(proto.FLOAT, number=2,)
-    taxes = proto.MapField(proto.STRING, proto.FLOAT, number=3,)
-    costs = proto.MapField(proto.STRING, proto.FLOAT, number=4,)
-    currency_code = proto.Field(proto.STRING, number=6,)
+    id: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    revenue: float = proto.Field(
+        proto.FLOAT,
+        number=2,
+    )
+    taxes: MutableMapping[str, float] = proto.MapField(
+        proto.STRING,
+        proto.FLOAT,
+        number=3,
+    )
+    costs: MutableMapping[str, float] = proto.MapField(
+        proto.STRING,
+        proto.FLOAT,
+        number=4,
+    )
+    currency_code: str = proto.Field(
+        proto.STRING,
+        number=6,
+    )
 
 
 class ProductDetail(proto.Message):
@@ -392,16 +500,40 @@ class ProductDetail(proto.Message):
             product in the user event.
     """
 
-    id = proto.Field(proto.STRING, number=1,)
-    currency_code = proto.Field(proto.STRING, number=2,)
-    original_price = proto.Field(proto.FLOAT, number=3,)
-    display_price = proto.Field(proto.FLOAT, number=4,)
-    stock_state = proto.Field(
-        proto.ENUM, number=5, enum=catalog.ProductCatalogItem.StockState,
+    id: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    currency_code: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    original_price: float = proto.Field(
+        proto.FLOAT,
+        number=3,
+    )
+    display_price: float = proto.Field(
+        proto.FLOAT,
+        number=4,
+    )
+    stock_state: catalog.ProductCatalogItem.StockState = proto.Field(
+        proto.ENUM,
+        number=5,
+        enum=catalog.ProductCatalogItem.StockState,
+    )
+    quantity: int = proto.Field(
+        proto.INT32,
+        number=6,
+    )
+    available_quantity: int = proto.Field(
+        proto.INT32,
+        number=7,
+    )
+    item_attributes: common.FeatureMap = proto.Field(
+        proto.MESSAGE,
+        number=8,
+        message=common.FeatureMap,
     )
-    quantity = proto.Field(proto.INT32, number=6,)
-    available_quantity = proto.Field(proto.INT32, number=7,)
-    item_attributes = proto.Field(proto.MESSAGE, number=8, message=common.FeatureMap,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
