@@ -1311,7 +1311,7 @@ def test_predict_rest_required_fields(request_type=prediction_service.PredictReq
 
             response = client.predict(request)
 
-            expected_params = []
+            expected_params = [("$alt", "json;enum-encoding=int")]
             actual_params = req.call_args.kwargs["params"]
             assert expected_params == actual_params
 
